.. :changelog:

Release History
---------------

0.1 (2016-05-17)
++++++++++++++++

Initial release. It is possible to start with a batch of pdf files that do not
yet have a prepared signature, and sign them.
